==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafregional/kotlin/inputs/WebAclRuleActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafregional.kotlin.inputs

import com.pulumi.aws.wafregional.inputs.WebAclRuleActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
 */
public data class WebAclRuleActionArgs(
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafregional.inputs.WebAclRuleActionArgs> {
    override fun toJava(): com.pulumi.aws.wafregional.inputs.WebAclRuleActionArgs =
        com.pulumi.aws.wafregional.inputs.WebAclRuleActionArgs.builder()
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAclRuleActionArgs].
 */
@PulumiTagMarker
public class WebAclRuleActionArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    /**
     * @param value Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
     */
    @JvmName("ykwnebsklclkcbsi")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
     */
    @JvmName("cbivfngvwgvucngu")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): WebAclRuleActionArgs = WebAclRuleActionArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafregional/kotlin/inputs/WebAclRuleActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafregional.kotlin.inputs

import com.pulumi.aws.wafregional.inputs.WebAclRuleActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
 */
public data class WebAclRuleActionArgs(
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafregional.inputs.WebAclRuleActionArgs> {
    override fun toJava(): com.pulumi.aws.wafregional.inputs.WebAclRuleActionArgs =
        com.pulumi.aws.wafregional.inputs.WebAclRuleActionArgs.builder()
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAclRuleActionArgs].
 */
@PulumiTagMarker
public class WebAclRuleActionArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    /**
     * @param value Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
     */
    @JvmName("ljwflrwxwyfhuvnw")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
     */
    @JvmName("kbhortvnibuiegxr")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): WebAclRuleActionArgs = WebAclRuleActionArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
